@@ -309,6 +309,7 @@ UnLslRLine(	char *const line,
 -rw-rw-r--   1 gleason  sysdevzz     1829 Jul 7   1996 README
 -rw-rw-r--   1 gleason  sysdevzz     1829 Jul  7 1996  README
 -rw-rw-r--   1 gleason  sysdevzz     1829 Jul 7  1996  README
+drwxrwxrwx   1 pvr pvr              45056 Jan  1 2000 DataFiles
          *
 	 *------------------------------^
 	 *                              0123456789012345
@@ -348,7 +349,12 @@ UnLslRLine(	char *const line,
 				cp[1] = '\0';	/* end size */
 				cp[5] = '\0';	/* end mon */
 				cp[8] = '\0';	/* end day */
-				cp[14] = '\0';	/* end year */
+				if (! isspace((int) filestart[-1])) {
+					if (isspace((int) filestart[-2])) {
+						filestart--;
+					}
+				}
+				filestart[-1] = '\0';	/* end year */
 				mon = LsMonthNameToNum(monstart);
 				day = atoi(daystart);
 				hr = 23;
@@ -941,8 +947,13 @@ UnMlsD(const FTPCIPtr cip, FTPFileInfoListPtr filp, FTPLineListPtr llp)
 				m1 = (mli.mode & 00700) >> 6;
 				m2 = (mli.mode & 00070) >> 3;
 				m3 = (mli.mode & 00007);
-			}
-			if (mli.perm[0] != '\0') {
+			} else if (mli.perm[0] != '\0') {
+				/* Note that if both UNIX.mode and
+				 * perm are avaiable, we will use
+				 * UNIX.mode.  This is probably
+				 * not what the RFC would like
+				 * us to do.
+				 */
 				m3 = 0;
 				if (fi.type == 'd') {
 					if (strchr(mli.perm, 'e') != NULL) {
