@@ -1,6 +1,6 @@
 /* shell.h
  *
- * Copyright (c) 1992-2003 by Mike Gleason.
+ * Copyright (c) 1992-2004 by Mike Gleason.
  * All rights reserved.
  * 
  */
@@ -72,7 +72,7 @@ CommandPtr GetCommandByIndex(const int);
 CommandPtr GetCommandByName(const char *const, int);
 void PrintCmdHelp(CommandPtr);
 void PrintCmdUsage(CommandPtr);
-int MakeArgv(char *, int *, char **, int, char *, size_t, int *, int);
+int MakeArgv(char *, int *, char **, int, char *, size_t, int *, int, int);
 void XferCanceller(int);
 void BackToTop(int);
 void Cancel(int);
