@@ -235,8 +235,9 @@ main(int argc, char **argv)
 	postcmd[0] = '\0';
 	perfilecmd[0] = '\0';
 
+#define kGetoptOptions "P:u:j:p:h:e:d:t:aRTr:vVf:o:ADzZEFbcCB:W:X:Y:I:"
 	GetoptReset(&opt);
-	while ((c = Getopt(&opt, argc, argv, "P:u:j:p:h:e:d:t:aRTr:vVf:ADzZEFbcCB:W:X:Y:I:")) > 0) {
+	while ((c = Getopt(&opt, argc, argv, kGetoptOptions)) > 0) {
 		if (c == 'b') {
 			batchmode++;
 		}
@@ -244,7 +245,7 @@ main(int argc, char **argv)
 
 	if (batchmode > 0) {
 		GetoptReset(&opt);
-		while ((c = Getopt(&opt, argc, argv, "P:u:j:p:h:e:d:U:t:mar:RvVf:o:AT:S:EFcCyZzDbB:W:X:Y:I:")) > 0) switch(c) {
+		while ((c = Getopt(&opt, argc, argv, kGetoptOptions)) > 0) switch(c) {
 			case 'v': case 'V': case 'A': case 'B': case 'T':
 			case 'd': case 'e': case 't': case 'r': case 'c':
 			case 'z': case 'Z': case 'C':
@@ -255,7 +256,7 @@ main(int argc, char **argv)
 	}
 
 	GetoptReset(&opt);
-	while ((c = Getopt(&opt, argc, argv, "P:u:j:p:h:e:d:t:aRTr:vVf:o:ADzZEFbcCB:W:X:Y:I:")) > 0) switch(c) {
+	while ((c = Getopt(&opt, argc, argv, kGetoptOptions)) > 0) switch(c) {
 		case 'P':
 		case 'u':
 		case 'j':
@@ -481,7 +482,7 @@ main(int argc, char **argv)
 	 * options to override those settings.
 	 */
 	GetoptReset(&opt);
-	while ((c = Getopt(&opt, argc, argv, "P:u:j:p:h:e:d:t:aRTr:vVf:o:ADzZEFbcCB:W:X:Y:I:")) > 0) switch(c) {
+	while ((c = Getopt(&opt, argc, argv, kGetoptOptions)) > 0) switch(c) {
 		case 'P':
 			fi.port = atoi(opt.arg);	
 			break;
